**free

//---<CREATE_OBJECTS>--------------------------------------------------------------------------------------------------------------------------------
//
//    @compile{
//             CRTSQLRPGI OBJ(&O/&N)
//                        SRCFILE(&L/&F)
//                        SRCMBR(&N)
//                        OBJTYPE(*MODULE)
//                        OPTION(*EVENTF)
//                        REPLACE(*YES)
//                        RPGPPOPT(*LVL2)
//                        DBGVIEW(*SOURCE)
//           }
//
//    @create{
//             CRTPGM PGM(&O/&N)
//                    MODULE(&O/&N)
//                    BNDSRVPGM(
//                                 (*LIBL/HTTP)
//                             )
//                    ACTGRP(*NEW)
//            }
//
//---</CREATE_OBJECTS>-------------------------------------------------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------------------------------------------------------------------
//
//  @name    WSCPW3R01
//
//  @purpose REST - Service Consumer
//
//  @author  Klaus-Peter Luttkus
//
//  @version 1.0.0 - 2020-05-06
//
//---------------------------------------------------------------------------------------------------------------------------------------------------

ctl-opt main(Main);

/if defined(*crtbndrpg)
   ctl-opt actgrp(*new);
/endif

ctl-opt alwnull(*usrctl);
ctl-opt option(*nodebugio:*srcstmt:*nounref);


/include QPOW3RSRC,HTTP_H
/include QPOW3RSRC,HTTP_C
/include QPOW3RSRC,HTTP_P

/include QRPG191209,CUSTOMER_H

exec sql set option naming = *sys, commit=*none;

dcl-proc Main;
  dcl-pi *n extpgm('WSPW3R01');

  end-pi;

  dcl-s lclFirma zoned(2) inz(1);
  dcl-s lclSearch char(120) inz('EPOS');

  dcl-s lclHandle like(tmplHandle);
  dcl-s lclRequestCLOB sqltype(CLOB:5000000);
  dcl-s lclRequest like(tmplHTTPBuffer) inz;
  dcl-s lclResponse like(tmplHTTPBuffer) inz;
  dcl-s lclEndPoint like(tmplURI) inz('http://172.16.111.23:10010//web/services/SQL_getCustomersByCompany/{p1}/{p2}');
  dcl-s retCode ind inz(*on);

  monitor;

     setLogging(*on:'/tmp/axislog00' + %char(%timestamp()) + '.log');
     if processParms(lclEndPoint:lclFirma:lclSearch) <> '*ERROR';
        if createTransport(lclEndPoint:lclHandle);
           setHTTPMethod(lclHandle:GET);
           sendRequest(lclHandle:lclRequest);
           getResponse(lclHandle:lclResponse);
           processResponse(lclResponse);
           destroyService(lclHandle);
           exec sql commit;
        else;
          dsply 'Transportobjekt nicht erstellt.';
        endif;
     else;
          dsply 'Endpoint ungltig';
     endif;
  on-error;
     retCode = *off;
  endmon;

  return;

end-proc;


//---------------------------------------------------------------------------------------------------------------------------------------------------
//
//  @name    processResponse
//
//---------------------------------------------------------------------------------------------------------------------------------------------------

dcl-proc processResponse;
  dcl-pi *n ind;
      inResponse like(tmplHTTPBuffer) const;
  end-pi;

  dcl-s lclResponse varchar(32000);

  dcl-ds lclCustomer likeds(tmplCustomerRec) dim(*auto:10000);

  dcl-s retCode ind inz(*on);


  monitor;


     lclResponse = %trim(inResponse);


     exec sql declare KundenDaten insensitive cursor for
               select * from Json_table(:lclResponse,
                                        '$.SQL_getCustomersByCompany_GetAll_R[*]'
                                        COLUMNS(
                                                 Firma decimal(2, 0) path '$.KLFINR',
                                                 Ident decimal(7, 0) path '$.KLIDNR',
                                                 Name1 char(32) path '$.KLNAM1'
                                                 // ... weiter Felder
                                                )
                  )as Data;

     exec sql open KundenDaten;
     if sqlcode = 0;
        exec sql fetch KundenDaten for 10000 rows INTO :lclCustomer;
        // ... Daten weiter verarbeiten
     endif;

     exec sql close KundenDaten;

  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


//---------------------------------------------------------------------------------------------------------------------------------------------------
//
//  @name    processParms
//
//  @purpose Erluternder Text
//
//
//
//  @author  Name
//
//  @param   Name Zweck
//
//  @return  Datentyp Zweck
//---------------------------------------------------------------------------------------------------------------------------------------------------

dcl-proc processParms;
  dcl-pi *n like(tmplURI);
      inEndPoint like(tmplURI) const;
      inFirma zoned(2) const;
      inSearch char(120) const;
  end-pi;

  dcl-s retEndPoint like(tmplURI) inz;

  monitor;
     retEndPoint = %scanrpl('{p1}': %char(inFirma):inEndPoint);
     retEndPoint = %scanrpl('{p2}': %char(%trim(inSearch)):retEndPoint);
  on-error;
     retEndPoint = '*ERROR';
  endmon;

  return retEndPoint;

on-exit;

end-proc;

